kaleo
=====

a user to user join invitations app


To Document
-----------

* Project Level Integration
** customizing the `signup_codes/invite_user.txt` email template
** using the `{% invite_form %}` and `{% invite_sent %}` template tags
** added the ajax javascript to submit the form and display the results/errors
* Settings
** Default Expiration
* Management Commands
** add_invites
** topoff_invites
* Templates
** _invite_form.html
** _invited.html
